@@ -12,6 +12,21 @@ use vars qw(
   $Config
 );
 
+
+#==============================================================================
+sub before_run
+{
+  my ($s, $asp, @args) = @_;
+}# end before_run()
+
+
+#==============================================================================
+sub after_run
+{
+  my ($s, $asp, @args) = @_;
+}# end after_run()
+
+
 #==============================================================================
 sub run
 {
