@@ -177,7 +177,11 @@ sub ServerVariables
   {
     return sort keys %ENV;
   }# end if()
-}# end ServerVariables()
+}# end ServerVariables()\
+
+
+#==============================================================================
+sub asp { $_[0]->{asp} }
 
 
 #==============================================================================
